@@ -1,4 +1,4 @@
-use serde::Deserialize;
+use {serde::Deserialize, serde_json::json};
 
 use crate::{
     entities::{Message, User},
@@ -42,4 +42,13 @@ impl GroupChannel {
             None => Ok(None),
         }
     }
+
+    /// Send a message in this channel.
+    pub async fn send(&self, cx: &Context, content: &str) -> Result<Message> {
+        let path = format!("channels/{}/messages", self.id);
+        let body = json!({ "content": content });
+        let msg = cx.http_client.post(&path, body).await?;
+
+        Ok(msg)
+    }
 }
